# Mastering Azure Machine Learning - Second Edition

<a href="https://www.packtpub.com/product/mastering-azure-machine-learning-second-edition/9781803232416?utm_source=github&utm_medium=repository&utm_campaign=9781803232416"><img src="https://static.packt-cdn.com/products/9781803232416/cover/smaller" alt="Mastering Azure Machine Learning - Second Edition" height="256px" align="right"></a>

This is the code repository for [Mastering Azure Machine Learning - Second Edition](https://www.packtpub.com/product/mastering-azure-machine-learning-second-edition/9781803232416?utm_source=github&utm_medium=repository&utm_campaign=9781803232416), published by Packt.


**Execute large-scale end-to-end machine learning with Azure**

## What is this book about?
Azure Machine Learning is a cloud service for accelerating and managing the machine learning (ML) project life cycle that ML professionals, data scientists, and engineers can use in their day-to-day workflows. This book covers the end-to-end ML process using Microsoft Azure Machine Learning, including data preparation, performing and logging ML training runs, designing training and deployment pipelines, and managing these pipelines via MLOps.

This book covers the following exciting features: 
* Understand the end-to-end ML pipeline
* Get to grips with the Azure Machine Learning workspace
* Ingest, analyze, and preprocess datasets for ML using the Azure cloud
* Train traditional and modern ML techniques efficiently using Azure ML
* Deploy ML models for batch and real-time scoring
* Understand model interoperability with ONNX
* Deploy ML models to FPGAs and Azure IoT Edge
* Build an automated MLOps pipeline using Azure DevOps

If you feel this book is for you, get your [copy](https://www.amazon.com/dp/B09NC5XJ6D) today!

<a href="https://www.packtpub.com/?utm_source=github&utm_medium=banner&utm_campaign=GitHubBanner"><img src="https://raw.githubusercontent.com/PacktPublishing/GitHub/master/GitHub.png" 
alt="https://www.packtpub.com/" border="5" /></a>


## Instructions and Navigations
All of the code is organized into folders.

The code will look like the following:
```
# increase display of all columns of rows for pandas datasets
pd.set_option('display.max_columns', None)
pd.set_option('display.max_rows', None)
# create pandas dataframe
raw_df = tabdf.to_pandas_dataframe()
raw_df.head()
```

**Following is what you need for this book:**
This book is for machine learning engineers, data scientists, and machine learning developers who want to use the Microsoft Azure cloud to manage their datasets and machine learning experiments and build an enterprise-grade ML architecture using MLOps. This book will also help anyone interested in machine learning to explore important steps of the ML process and use Azure Machine Learning to support them, along with building powerful ML cloud applications. A basic understanding of Python and knowledge of machine learning are recommended.

### Software and Hardware List


This book requires the use of Azure services and therefore an Azure subscription. You
can create an Azure account for free and receive USD 200 of credits to use within 30 days
using the sign-up page at https://azure.microsoft.com/en-us/free/.

To run the authoring code, you can either use a compute instance in the Azure Machine
Learning workspace (typically a Standard_DS3_v2 virtual machine), which gives
you access to a Jupyter environment and all essential libraries preinstalled, or you can
run it on your own local machine. To do so, you need a Python runtime with the Jupyter
package installed and some additional libraries, which will be mentioned in the technical
requirements of each chapter. We tested all the code with Python version 3.8 and the
Azure ML Python SDK version 1.34.0 at the time of writing. If you want to work with a
different setup, be sure to check the supported Python version for the Azure ML Python
SDK (https://pypi.org/project/azureml-sdk/).

We also provide a PDF file that has color images of the screenshots/diagrams used in this book. [Click here to download it](https://static.packt-cdn.com/downloads/9781803232416_ColorImages.pdf).


### Related products <Other books you may enjoy>
* Azure Data Scientist Associate Certification Guide [[Packt]](https://www.packtpub.com/product/azure-data-scientist-associate-certification-guide/9781800565005?utm_source=github&utm_medium=repository&utm_campaign=9781800565005) [[Amazon]](https://www.amazon.com/dp/B09CQ4YLTN)

* Engineering MLOps [[Packt]](https://www.packtpub.com/product/engineering-mlops/9781800562882?utm_source=github&utm_medium=repository&utm_campaign=9781800562882) [[Amazon]](https://www.amazon.com/dp/B08PFN73CM)

## Get to Know the Authors
**Christoph Körner**
previously worked as a cloud solution architect for Microsoft, specializing
in Azure-based big data and machine learning solutions, where he was responsible for
designing end-to-end machine learning and data science platforms. He currently works for
a large cloud provider on highly scalable distributed in-memory database services. Christoph
has authored four books: Deep Learning in the Browser for Bleeding Edge Press, as well as
Mastering Azure Machine Learning (first edition), Learning Responsive Data Visualization,
and Data Visualization with D3 and AngularJS for Packt Publishing.
  
**Marcel Alsdorf**
is a cloud solution architect with 5 years of experience at Microsoft
consulting various companies on their cloud strategy. In this role, he focuses on supporting
companies in their move toward being data-driven by analyzing their requirements
and designing their data infrastructure in the areas of IoT and event streaming, data
warehousing, and machine learning. On the side, he shares his technical and business
knowledge as a coach in hackathons, as a mentor for start-ups and peers, and as a university
lecturer. Before his current role, he worked as an FPGA engineer for the LHC project at
CERN and as a software engineer in the banking industry
